Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3483)

Unified Diff: chrome/browser/ui/views/dropdown_bar_host.cc

Issue 23531053: ui/base/animation -> ui/gfx/animation (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Merge 2 trunk Created 7 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/dropdown_bar_host.cc
diff --git a/chrome/browser/ui/views/dropdown_bar_host.cc b/chrome/browser/ui/views/dropdown_bar_host.cc
index 1d150c81953aa4f63de6d7193dffa0ee03ad9c8f..c509cfd56e0fed80a34342fcbb9c6e5133e086f5 100644
--- a/chrome/browser/ui/views/dropdown_bar_host.cc
+++ b/chrome/browser/ui/views/dropdown_bar_host.cc
@@ -10,8 +10,8 @@
#include "chrome/browser/ui/views/dropdown_bar_host_delegate.h"
#include "chrome/browser/ui/views/dropdown_bar_view.h"
#include "chrome/browser/ui/views/frame/browser_view.h"
-#include "ui/base/animation/slide_animation.h"
#include "ui/base/keycodes/keyboard_codes.h"
+#include "ui/gfx/animation/slide_animation.h"
#include "ui/gfx/path.h"
#include "ui/gfx/scrollbar_size.h"
#include "ui/views/focus/external_focus_tracker.h"
@@ -86,7 +86,7 @@ void DropdownBarHost::Init(views::View* host_view,
}
// Start the process of animating the opening of the widget.
- animation_.reset(new ui::SlideAnimation(this));
+ animation_.reset(new gfx::SlideAnimation(this));
}
DropdownBarHost::~DropdownBarHost() {
@@ -183,9 +183,9 @@ void DropdownBarHost::OnDidChangeFocus(views::View* focused_before,
}
////////////////////////////////////////////////////////////////////////////////
-// DropdownBarHost, ui::AnimationDelegate implementation:
+// DropdownBarHost, gfx::AnimationDelegate implementation:
-void DropdownBarHost::AnimationProgressed(const ui::Animation* animation) {
+void DropdownBarHost::AnimationProgressed(const gfx::Animation* animation) {
// First, we calculate how many pixels to slide the widget.
gfx::Size pref_size = view_->GetPreferredSize();
animation_offset_ = static_cast<int>((1.0 - animation_->GetCurrentValue()) *
@@ -202,7 +202,7 @@ void DropdownBarHost::AnimationProgressed(const ui::Animation* animation) {
view_->SchedulePaint();
}
-void DropdownBarHost::AnimationEnded(const ui::Animation* animation) {
+void DropdownBarHost::AnimationEnded(const gfx::Animation* animation) {
// Place the dropdown widget in its fully opened state.
animation_offset_ = 0;
« no previous file with comments | « chrome/browser/ui/views/dropdown_bar_host.h ('k') | chrome/browser/ui/views/extensions/extension_install_dialog_view.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698